@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 692 $
+# Revision: $Rev: 748 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -26,6 +26,7 @@
 from qt import QImage, QPixmap, QLabel, QGridLayout, PYSIGNAL
 from qt import QImageDrag, QDragObject, QSizePolicy, QPopupMenu, QIconSet
 from qt import QCursor, QPixmap, QFileDialog, QMessageBox, QFileDialog
+from qt import QDockWindow
 
 
 #-- Python imports
@@ -353,7 +354,7 @@ class DropLabel(QLabel):
 
 
 
-class PicturePreview(PicturePreviewBase):
+class PicturePreview(PicturePreviewBase, QDockWindow):
     """displays a picture and scales it appropriately"""
     def __init__(self, dirname, parent=None, name=None, fl=0):
         PicturePreviewBase.__init__(self, parent, name, fl)
@@ -829,10 +830,10 @@ if (__name__ == "__main__"):
     log.setLevel(pref['logLevel'])
 
     # read sample record
-    f = AMCFile33(u"/home/merkosh/Projekte/Film- Mp3- Hörspiellisten/Filme/LMC/Filme.amc", "rb")
+    f = AMCFile33(u"/home/merkosh/src/Film- Mp3- Hörspiellisten/Filme/LMC/Filme.amc", "rb")
     rec = f.read()[-1]
 
-    w = PicturePreview(u"/home/merkosh/Projekte/Film- Mp3- Hörspiellisten/Filme/LMC")
+    w = PicturePreview(u"/home/merkosh/src/Film- Mp3- Hörspiellisten/Filme/LMC")
     w.setRecord(rec)
 
     a.setMainWidget(w)
