@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 692 $
+# Revision: $Rev: 748 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -24,7 +24,7 @@
 #-- imports --------------------------------------------------------------------
 #-- Qt imports
 from qt import SIGNAL, QListView, QListViewItem, QGridLayout, QSize, QTimer
-from qt import PYSIGNAL, QImage, QPixmap, QApplication
+from qt import PYSIGNAL, QImage, QPixmap, QApplication, QDockArea
 
 
 #-- Python imports
@@ -63,7 +63,6 @@ class RecordList(RecordListBase):
     """
     def __init__(self, dirname, parent=None, name=None, fl=0):
         RecordListBase.__init__(self, parent, name, fl)
-
         # create logging
         self.log = logging.getLogger( self.__class__.__name__ )
         self.log.setLevel(pref['logLevel'])
