@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 546 $
+# Revision: $Rev: 692 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -18,24 +18,24 @@
 #    You should have received a copy of the GNU General Public License     #
 #    along with this program; if not, write to the                         #
 #    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
+#    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          #
 ############################################################################
 import os
 from os.path import join as fjoin, exists as fexists
 
 
-pythondir = "${prefix}/lib/python2.3/site-packages".replace('${prefix}', "/usr/local")
+pythondir = "${prefix}/lib/python2.4/site-packages".replace('${prefix}', "prefix")
 installdir = fjoin(pythondir, "lmc")
 
-if (os.getcwd() == "/home/merkosh/Projekte/lmc/src"):
+if (os.getcwd() == "/home/merkosh/src/lmc/src"):
 	installdir = "."
 
-version = "0.12.4"
+version = "0.12.8"
 scriptdir = fjoin(installdir, "scripts")
 resourcedir = fjoin(installdir, "resources")
 
 use_listviewsort = ("yes" == "yes")
 
 have_eject = ("/usr/bin/eject" != "no")
-have_tcprobe = ("/usr/bin/tcprobe" != "no")
+have_tcprobe = ("/home/merkosh/usr/bin/tcprobe" != "no")
 
