@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 # Author:   $Author: merkosh $
-# Revision: $Rev: 579 $
+# Revision: $Rev: 754 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -18,7 +18,7 @@
 #    You should have received a copy of the GNU General Public License     #
 #    along with this program; if not, write to the                         #
 #    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
+#    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          #
 ############################################################################
 
 #-----------------------------------------------------------#
@@ -76,7 +76,7 @@ if (substr($ARGV[0], 0,7) eq 'http://') {
 
 
 #-- scan amazon ----------------------------------------------------------------
-$baseURL = 'http://www.amazon.com';
+#$baseURL = 'http://www.amazon.com';
 $searchURL = 'http://www.amazon.com/exec/obidos/search-handle-url/index=dvd&field-title=';
 
 
@@ -92,30 +92,36 @@ if ($title) {
   $page = getPage($searchURL.uri_escape($title))->content();
 
   # try to get number of hits to calculate number of consecutive pages
-  if ($page =~ /All (\d+) results for/) {
-    $pageCount = ceil($1 /10);	       # ten hits per page
-    $pageCount++ if ($1 % 10 < 5);     # no ceil function in perl (?!)
-  }
+  $matches = ($page =~ /Showing (\d+) (- (\d+) of (\d+) Results)?/);
+  $pageCount = 1;
+  $pageCount = ceil($3 /$4) if (($matches) & ($matches > 1));
 
   # process all pages
   for ($pg=1; $pg <= $pageCount; $pg++){
     # search for links which look like our target
     $tree = HTML::TreeBuilder->new();
     $tree->parse($page);
-    @links = @{$tree->extract_links()};
+    # need all <a href="..."> tags
+    @links = @{$tree->extract_links('a', 'href')};
 
     # filter target links
-    foreach (@links){
-      if ((substr($_->[0], 0, 23) eq "/exec/obidos/tg/detail/") && # URL matches this prefix
-	  (ref $_->[1]->content() eq "ARRAY") &&                  # 
-	  (ref @{$_->[1]->content()}[0] ne "HTML::Element") &&    # link is clear text description
-	  (@{$_->[1]->content()}[0] !~ /buy|in\-store/i)          # link is text and does not contain "buy" and "in-store"	    
-	  ) {
+    foreach $anchor (@links){
+      # the href must have the form: http://www.amazon.com/.../dp/
+      $link_href = $anchor->[1]->attr_get_i('href');
+      if ($link_href =~ /http\:\/\/www\.amazon\.com\/.+?\/dp\//) {
+	# the child of the a-tag must be a span-tag
+	@children = $anchor->[1]->content_list();
+	foreach $child (@children) {
+  	  next if (ref($child) ne "HTML::Element");
+	  next if ($child->tag() ne "span");
 
-	$tlinks{$_->[0]} = $_->[1];		  # target link found
+	  # the (only) child of the span-tag is the text description
+	  @names = $child->content_list();
+	  $tlinks{$names[0]} = $link_href if (scalar @names == 1);
+	}
       }
     }
-    
+
     # download next page
     if ($pg < $pageCount) {
       $page = getPage($searchURL.uri_escape($title)."&pg=".($pg+1))->content();
@@ -124,8 +130,8 @@ if ($title) {
 
   # scan for url and text
   foreach (keys %tlinks){
-    push @match, {Text => $tlinks{$_}->content()->[0],
-		  URL => $tlinks{$_}->attr('href')}
+    push @match, {Text => $_, 
+		  URL => $tlinks{$_}};
   }
 
 
@@ -135,7 +141,7 @@ if ($title) {
 
   foreach $rec (@match){
     print "title: $rec->{Text}\n";
-    print "url: $baseURL$rec->{URL}\n";
+    print "url: $rec->{URL}\n";
     print "\n";
   }
   exit;
@@ -172,17 +178,27 @@ if ($URL){
   # - producer
 
   # picture
-  if ($URL !~ /detail\/\-\/(.+?)\?/) {
+  if ($URL !~ /\/dp\/(.+?)$/) {
     print "status: error\n";
     print STDERR "url: $URL\n";
     print STDERR "Could not extract picture ID from URL\n";
   }
   $ID = $1;
 
-  if ($page =~ /\"(http\:\/\/images\.amazon\.com\/images\/.+?\/$ID\..+?)\"/){
-    $data{picture} = $1;
-  }
+  # double-link image
+  $URL2 = "http://www.amazon.com/gp/product/images/".$ID;
+  
+  $response = getPage($URL2);
+  $page = $response->content();
 
+  $tree = HTML::TreeBuilder->new();
+  $tree->parse($page);
+
+  @result = $tree->find_by_attribute('id', 'prodImage');
+
+  $data{picture} = $result[0]->attr('src') if (scalar @result);
+
+  
   #-- output
   print "status: details\n";
 
